==> pdf-model-arlington-1.25.15-sources.jar: org/verapdf/model/alayer/AIconFit.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AIconFit extends AObject {
	


	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public Boolean getAHasTypeArray();

	/**
	*/
	public Boolean getcontainsFB();

	/**
	*/
	public Boolean getFBHasTypeBoolean();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsSW();

	/**
	*/
	public Boolean getSWHasTypeName();

	/**
	*/
	public String getSWNameValue();

	/**
	*/
	public Double getA1NumberValue();

	/**
	*/
	public Double getA0NumberValue();

	/**
	*/
	public Boolean getA1HasTypeNumber();

	/**
	*/
	public Boolean getA0HasTypeNumber();
}

==> pdf-model-arlington-1.26.2-sources.jar: org/verapdf/model/alayer/AIconFit.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AIconFit extends AObject {
	


	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public String getAType();

	/**
	*/
	public Boolean getAHasTypeArray();

	/**
	*/
	public Boolean getcontainsFB();

	/**
	*/
	public String getFBType();

	/**
	*/
	public Boolean getFBHasTypeBoolean();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public String getSType();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsSW();

	/**
	*/
	public String getSWType();

	/**
	*/
	public Boolean getSWHasTypeName();

	/**
	*/
	public String getSWNameValue();

	/**
	*/
	public Double getA0NumberValue();

	/**
	*/
	public Double getA1NumberValue();

	/**
	*/
	public Boolean getA0HasTypeNumber();

	/**
	*/
	public Boolean getA1HasTypeNumber();
}
